@@ -272,7 +272,7 @@ class DBWriter(object):
         try_simple = False
         try:
             cur.copy_from(out, sep='|', size=134217728,
-                      table = f'public.{self.tname_temp}',
+                      table = self.tname_temp,
                       null="")
             raw_con.commit()
         except psycopg2.errors.BadCopyFileFormat:
